@@ -52,7 +52,7 @@ if (typeof tinyMCE != 'undefined') {
         theme_advanced_toolbar_location: "top",
         theme_advanced_toolbar_align: "left",
         theme_advanced_statusbar_location: "",
-        theme_advanced_buttons1: "bold,italic,|,link,unlink,|,image,|,media,charmap,|,code,|,table,|,bullist,numlist,blockquote,|,undo,redo,|,formatselect",
+        theme_advanced_buttons1: "bold,italic,|,link,unlink,|,image,|,media,charmap,|,code,|,table,|,bullist,numlist,blockquote,|,undo,redo,|,formatselect,|,cite,ins,del,abbr,acronym,attribs,",
         theme_advanced_buttons2: "",
         theme_advanced_buttons3: "",
         theme_advanced_path: false,
@@ -65,7 +65,7 @@ if (typeof tinyMCE != 'undefined') {
         advlink_styles: "intern=internal;extern=external",
 
         // plugins
-        plugins: "advimage,advlink,paste,media,table",
+        plugins: "advimage,advlink,paste,media,table,xhtmlxtras",
         advimage_update_dimensions_onchange: true,
 
         // remove MS Word's inline styles when copying and pasting.
@@ -77,38 +77,42 @@ if (typeof tinyMCE != 'undefined') {
 
         // elements
         valid_elements : ""
-        + "span[style],"
-        + "-p,"
-        + "a[href|target=_blank|class],"
-        + "-strong/-b,"
-        + "-em/-i,"
-        + "-u,"
-        + "-ol,"
-        + "-ul,"
-        + "-li,"
-        + "-dl,"
-        + "-dd,"
-        + "-dt,"
-        + "br,"
-        + "img[class|src|alt=|width|height],"
-        + "-h2,-h3,-h4,"
-        + "-pre,"
-        + "-blockquote,"
-        + "-code,"
-        + "-table[border=0|cellspacing|cellpadding|width|frame|rules|height|"
-        + "align|summary|bgcolor|background|bordercolor],"
-        + "-tr[rowspan|width|height|align|valign|bgcolor|"
-        + "background|bordercolor],"
-        + "tbody,"
-        + "thead,"
-        + "tfoot,"
-        + "#td[colspan|rowspan|width|height|align|valign|bgcolor|background|"
-        + "bordercolor|scope],"
-        + "#th[colspan|rowspan|width|height|align|valign|scope],"
-        + "-div",
+		+ "span[style],"
+		+ "-p,"
+		+ "a[href|target=_blank|class],"
+		+ "-strong/-b,"
+		+ "-em/-i,"
+		+ "-u,"
+		+ "-ol,"
+		+ "-ul,"
+		+ "-li,"
+		+ "-dl,"
+		+ "-dd,"
+		+ "-dt,"
+		+ "br,"
+		+ "img[class|src|alt=|width|height],"
+		+ "-h2,-h3,-h4,"
+		+ "-pre,"
+		+ "-blockquote,"
+		+ "-cite,"
+		+ "-code,"
+		+ "-iframe,"
+		+ "-table[border=0|cellspacing|cellpadding|width|frame|rules|height|"
+		+ "align|summary|bgcolor|background|bordercolor],"
+		+ "-tr[rowspan|width|height|align|valign|bgcolor|"
+		+ "background|bordercolor],"
+		+ "tbody,"
+		+ "thead,"
+		+ "tfoot,"
+		+ "#td[colspan|rowspan|width|height|align|valign|bgcolor|background|"
+		+ "bordercolor|scope],"
+		+ "#th[colspan|rowspan|width|height|align|valign|scope],"
+		+ "-div,"
+		+ "",
         extended_valid_elements: "pre[style],"
         + "a[name|class|href|target|title|onclick],"
         + "img[class|src|border=0|alt|title|hspace|vspace|width|height|align|onmouseover|onmouseout|name],"
+        + "iframe[src|title|byline|portrait|frameborder|width|height],"
         + "br[clearfix],"
         + "-p[class<clearfix?summary?code],"
         + "h2[class<clearfix],h3[class<clearfix],h4[class<clearfix],"
@@ -125,7 +129,8 @@ if (typeof tinyMCE != 'undefined') {
         + "h1/h2/h3/h4/h5/h6/a[%itrans_na],"
         + "table[thead|tbody|tfoot|tr|td],"
         + "strong/b/p/div/em/i/td[%itrans|#text],"
-        + "body[%btrans|#text]"
-    });
+		//+ "body[%btrans|#text]"
+        + "",
+	});
 
 }
