@@ -1,4 +1,3 @@
-
 from datetime import datetime
 
 from django.contrib.contenttypes.generic import GenericForeignKey
@@ -67,9 +66,6 @@ class Slugged(models.Model):
             self.site = Site.objects.get_current()
         super(Slugged, self).save(*args, **kwargs)
 
-    def natural_key(self):
-        return (self.slug,)
-
     def get_slug(self):
         """
         Allows subclasses to implement their own slug creation logic.
