@@ -14,13 +14,17 @@ def admin_keywords_submit(request):
     admin, and returns their IDs for use when saving a model with a
     keywords field.
     """
-    ids = []
+    ids, titles = [], []
     for title in request.POST.get("text_keywords", "").split(","):
-        title = "".join([c for c in title if c.isalnum() or c in "- "]).lower()
+        title = "".join([c for c in title if c.isalnum() or c in "- "])
+        title = title.strip().lower()
         if title:
             keyword, created = Keyword.objects.get_or_create(title=title)
-            ids.append(str(keyword.id))
-    return HttpResponse(",".join(ids))
+            id = str(keyword.id)
+            if id not in ids:
+                ids.append(id)
+                titles.append(title)
+    return HttpResponse("%s|%s" % (",".join(ids), ", ".join(titles)))
 
 
 def rating(request):
