@@ -1,11 +1,10 @@
 
 from django.core.urlresolvers import resolve, reverse
 from django.db import models
-from django.template.defaultfilters import slugify
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.core.models import Displayable, Orderable, RichText
-from mezzanine.utils.urls import admin_url
+from mezzanine.utils.urls import admin_url, slugify
 
 
 class Page(Orderable, Displayable):
@@ -67,7 +66,7 @@ class Page(Orderable, Displayable):
         """
         slug = slugify(self.title)
         if self.parent is not None:
-            return "%s/%s" % (self.parent.get_slug(), slug)
+            return "%s/%s" % (self.parent.slug, slug)
         return slug
 
     def reset_slugs(self):
